@@ -21,7 +21,7 @@ require Exporter;
 
 our @ISA = qw(Exporter);
 
-$VERSION = "1.10";
+$VERSION = "1.11";
 
 @EXPORT_OK = qw(checkGripsResponse);
 
@@ -1437,7 +1437,13 @@ muss.
 
     1.10
 
-    - Fix package declaration=head1 AUTHOR
+    - Fix package declaration
+    
+    1.11
+
+    - Fix Makefile.PL
+    
+=head1 AUTHOR
 
 Tarek Ahmed, E<lt>ahmed@dimdi.deE<gt>
 
